import '../../../hooks/index.mjs';
import { resizableColumnProps } from './resizable-column2.mjs';
import { defineComponent, getCurrentInstance, inject, computed, ref, reactive, onMounted, onUnmounted, resolveComponent, openBlock, createElementBlock, Fragment, createElementVNode, normalizeClass, normalizeStyle, renderSlot, createBlock, withCtx, createVNode, createCommentVNode } from 'vue';
import '../../../utils/index.mjs';
import { resizableColumnsRootContextKey } from './constants.mjs';
import { ArrowLeft, ArrowRight } from '@element-plus/icons-vue';
import _export_sfc from '../../../_virtual/plugin-vue_export-helper.mjs';
import { throwError } from '../../../utils/error.mjs';
import { useNamespace } from '../../../hooks/use-namespace/index.mjs';

const _sfc_main = defineComponent({
  name: "ElResizableColumn",
  components: { ArrowLeft, ArrowRight },
  props: resizableColumnProps,
  emits: ["collapse", "expand"],
  setup(props, { emit, slots, expose }) {
    const instance = getCurrentInstance();
    const columnsRoot = inject(resizableColumnsRootContextKey);
    if (!columnsRoot)
      throwError("ElResizableColumn", "usage: <el-resizable-columns><el-resizable-column /></el-resizable-columns/>");
    const MIN_WIDTH = columnsRoot.props.minWidth > 0 ? columnsRoot.props.minWidth : 50;
    const collapsable = computed(() => props.collapsable || columnsRoot.props.collapsable);
    const collapsed = ref(false);
    const column = reactive({
      uid: instance.uid,
      slots,
      props,
      maxWidth: 0,
      parentWidth: 0,
      index: 0,
      length: 0,
      width: 0,
      left: 0,
      collapsable,
      collapsed
    });
    onMounted(() => {
      columnsRoot.registerColumn(column);
    });
    onUnmounted(() => {
      columnsRoot.unregisterColumn(column.uid);
    });
    const ns = useNamespace("resizable-column");
    const handleCollapse = () => {
      if (!collapsed.value) {
        for (let rIndex = column.index + 1; rIndex < columnsRoot.columns.value.length; rIndex++) {
          const rColumn = columnsRoot.columns.value[rIndex];
          if (!rColumn.collapsed) {
            rColumn.left = rColumn.left - column.width;
            rColumn.width = rColumn.width + column.width;
            break;
          } else {
            rColumn.left = rColumn.left - column.width;
          }
        }
        collapsed.value = true;
        emit("collapse", column.index);
      }
    };
    const handleExpand = () => {
      if (collapsed.value) {
        collapsed.value = false;
        const rightColumn = columnsRoot.columns.value[column.index + 1];
        rightColumn.left = rightColumn.left + column.width;
        rightColumn.width = rightColumn.width > column.width + MIN_WIDTH ? rightColumn.width - column.width : MIN_WIDTH;
        const allOtherColumns = columnsRoot.columns.value.slice(column.index + 2);
        const otherWidth = (column.parentWidth - rightColumn.left - rightColumn.width) / allOtherColumns.length;
        allOtherColumns.forEach((item, index) => {
          item.left = index * otherWidth + rightColumn.left + rightColumn.width;
          item.width = otherWidth;
        });
        emit("expand", column.index);
      }
    };
    return {
      ns,
      column,
      handleCollapse,
      handleExpand
    };
  }
});
const _hoisted_1 = ["widget"];
const _hoisted_2 = ["data-index"];
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_ArrowLeft = resolveComponent("ArrowLeft");
  const _component_el_icon = resolveComponent("el-icon");
  const _component_el_button = resolveComponent("el-button");
  const _component_ArrowRight = resolveComponent("ArrowRight");
  return openBlock(), createElementBlock(Fragment, null, [
    createElementVNode("div", {
      class: normalizeClass(_ctx.ns.b()),
      widget: _ctx.widget,
      style: normalizeStyle({ width: `${_ctx.column.width}px`, left: `${_ctx.column.left}px`, display: _ctx.column.collapsed ? "none" : "unset" })
    }, [
      renderSlot(_ctx.$slots, "default")
    ], 14, _hoisted_1),
    _ctx.column.index < _ctx.column.length - 1 ? (openBlock(), createElementBlock("div", {
      key: 0,
      class: normalizeClass(["resizer", { "collapsed": _ctx.column.collapsed }]),
      style: normalizeStyle({ left: `${_ctx.column.left + (_ctx.column.collapsed ? 0 : _ctx.column.width)}px` }),
      "data-index": _ctx.column.index
    }, [
      !_ctx.column.collapsed ? (openBlock(), createBlock(_component_el_button, {
        key: 0,
        class: "left",
        size: "small",
        onClick: _ctx.handleCollapse,
        disabled: !_ctx.column.collapsable
      }, {
        default: withCtx(() => [
          createVNode(_component_el_icon, null, {
            default: withCtx(() => [
              createVNode(_component_ArrowLeft)
            ]),
            _: 1
          })
        ]),
        _: 1
      }, 8, ["onClick", "disabled"])) : (openBlock(), createBlock(_component_el_button, {
        key: 1,
        class: "right",
        size: "small",
        onClick: _ctx.handleExpand,
        disabled: !_ctx.column.collapsable
      }, {
        default: withCtx(() => [
          createVNode(_component_el_icon, null, {
            default: withCtx(() => [
              createVNode(_component_ArrowRight)
            ]),
            _: 1
          })
        ]),
        _: 1
      }, 8, ["onClick", "disabled"]))
    ], 14, _hoisted_2)) : createCommentVNode("v-if", true)
  ], 64);
}
var ResizableColumn = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render], ["__file", "D:\\workspace\\element-pe\\packages\\components\\resizable-columns\\src\\resizable-column.vue"]]);

export { ResizableColumn as default };
//# sourceMappingURL=resizable-column.mjs.map
