'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

require('../../../hooks/index.js');
var resizableColumn = require('./resizable-column2.js');
var vue = require('vue');
require('../../../utils/index.js');
var constants = require('./constants.js');
var iconsVue = require('@element-plus/icons-vue');
var pluginVue_exportHelper = require('../../../_virtual/plugin-vue_export-helper.js');
var error = require('../../../utils/error.js');
var index = require('../../../hooks/use-namespace/index.js');

const _sfc_main = vue.defineComponent({
  name: "ElResizableColumn",
  components: { ArrowLeft: iconsVue.ArrowLeft, ArrowRight: iconsVue.ArrowRight },
  props: resizableColumn.resizableColumnProps,
  emits: ["collapse", "expand"],
  setup(props, { emit, slots, expose }) {
    const instance = vue.getCurrentInstance();
    const columnsRoot = vue.inject(constants.resizableColumnsRootContextKey);
    if (!columnsRoot)
      error.throwError("ElResizableColumn", "usage: <el-resizable-columns><el-resizable-column /></el-resizable-columns/>");
    const MIN_WIDTH = columnsRoot.props.minWidth > 0 ? columnsRoot.props.minWidth : 50;
    const collapsable = vue.computed(() => props.collapsable || columnsRoot.props.collapsable);
    const collapsed = vue.ref(false);
    const column = vue.reactive({
      uid: instance.uid,
      slots,
      props,
      maxWidth: 0,
      parentWidth: 0,
      index: 0,
      length: 0,
      width: 0,
      left: 0,
      collapsable,
      collapsed
    });
    vue.onMounted(() => {
      columnsRoot.registerColumn(column);
    });
    vue.onUnmounted(() => {
      columnsRoot.unregisterColumn(column.uid);
    });
    const ns = index.useNamespace("resizable-column");
    const handleCollapse = () => {
      if (!collapsed.value) {
        for (let rIndex = column.index + 1; rIndex < columnsRoot.columns.value.length; rIndex++) {
          const rColumn = columnsRoot.columns.value[rIndex];
          if (!rColumn.collapsed) {
            rColumn.left = rColumn.left - column.width;
            rColumn.width = rColumn.width + column.width;
            break;
          } else {
            rColumn.left = rColumn.left - column.width;
          }
        }
        collapsed.value = true;
        emit("collapse", column.index);
      }
    };
    const handleExpand = () => {
      if (collapsed.value) {
        collapsed.value = false;
        const rightColumn = columnsRoot.columns.value[column.index + 1];
        rightColumn.left = rightColumn.left + column.width;
        rightColumn.width = rightColumn.width > column.width + MIN_WIDTH ? rightColumn.width - column.width : MIN_WIDTH;
        const allOtherColumns = columnsRoot.columns.value.slice(column.index + 2);
        const otherWidth = (column.parentWidth - rightColumn.left - rightColumn.width) / allOtherColumns.length;
        allOtherColumns.forEach((item, index) => {
          item.left = index * otherWidth + rightColumn.left + rightColumn.width;
          item.width = otherWidth;
        });
        emit("expand", column.index);
      }
    };
    return {
      ns,
      column,
      handleCollapse,
      handleExpand
    };
  }
});
const _hoisted_1 = ["widget"];
const _hoisted_2 = ["data-index"];
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_ArrowLeft = vue.resolveComponent("ArrowLeft");
  const _component_el_icon = vue.resolveComponent("el-icon");
  const _component_el_button = vue.resolveComponent("el-button");
  const _component_ArrowRight = vue.resolveComponent("ArrowRight");
  return vue.openBlock(), vue.createElementBlock(vue.Fragment, null, [
    vue.createElementVNode("div", {
      class: vue.normalizeClass(_ctx.ns.b()),
      widget: _ctx.widget,
      style: vue.normalizeStyle({ width: `${_ctx.column.width}px`, left: `${_ctx.column.left}px`, display: _ctx.column.collapsed ? "none" : "unset" })
    }, [
      vue.renderSlot(_ctx.$slots, "default")
    ], 14, _hoisted_1),
    _ctx.column.index < _ctx.column.length - 1 ? (vue.openBlock(), vue.createElementBlock("div", {
      key: 0,
      class: vue.normalizeClass(["resizer", { "collapsed": _ctx.column.collapsed }]),
      style: vue.normalizeStyle({ left: `${_ctx.column.left + (_ctx.column.collapsed ? 0 : _ctx.column.width)}px` }),
      "data-index": _ctx.column.index
    }, [
      !_ctx.column.collapsed ? (vue.openBlock(), vue.createBlock(_component_el_button, {
        key: 0,
        class: "left",
        size: "small",
        onClick: _ctx.handleCollapse,
        disabled: !_ctx.column.collapsable
      }, {
        default: vue.withCtx(() => [
          vue.createVNode(_component_el_icon, null, {
            default: vue.withCtx(() => [
              vue.createVNode(_component_ArrowLeft)
            ]),
            _: 1
          })
        ]),
        _: 1
      }, 8, ["onClick", "disabled"])) : (vue.openBlock(), vue.createBlock(_component_el_button, {
        key: 1,
        class: "right",
        size: "small",
        onClick: _ctx.handleExpand,
        disabled: !_ctx.column.collapsable
      }, {
        default: vue.withCtx(() => [
          vue.createVNode(_component_el_icon, null, {
            default: vue.withCtx(() => [
              vue.createVNode(_component_ArrowRight)
            ]),
            _: 1
          })
        ]),
        _: 1
      }, 8, ["onClick", "disabled"]))
    ], 14, _hoisted_2)) : vue.createCommentVNode("v-if", true)
  ], 64);
}
var ResizableColumn = /* @__PURE__ */ pluginVue_exportHelper["default"](_sfc_main, [["render", _sfc_render], ["__file", "D:\\workspace\\element-pe\\packages\\components\\resizable-columns\\src\\resizable-column.vue"]]);

exports["default"] = ResizableColumn;
//# sourceMappingURL=resizable-column.js.map
